@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2007 Andrew Mihal
+ * Copyright (C) 2004-2012 Andrew Mihal
  *
  * This file is part of Enblend.
  *
@@ -7,16 +7,18 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * Enblend is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with Enblend; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
+
 #ifndef __GPU_H__
 #define __GPU_H__
 
@@ -27,25 +29,35 @@
 #ifdef HAVE_LIBGLEW
 #define GLEW_STATIC 1
 
-
 #include <GL/glew.h>
 #ifdef HAVE_APPLE_OPENGL_FRAMEWORK
-#include <GLUT/glut.h>
+#include <OpenGL/OpenGL.h>
 #else
 #include <GL/glut.h>
 #endif
 
-#define CHECK_GL() checkGLErrors(__LINE__, __FILE__)
+extern int Verbose;
+
+void checkGLErrors(const char* file, unsigned line);
+#define CHECK_GL() checkGLErrors(__FILE__, __LINE__)
 
-void checkGLErrors(int line, char *file);
 void printInfoLog(GLhandleARB obj);
 bool checkFramebufferStatus();
 
-bool initGPU(int *,char **);
-bool configureGPUTextures(unsigned int k, unsigned int vars);
-bool gpuGDAKernel(unsigned int k, unsigned int vars, double t, float *packedEData, float *packedPiData, float *packedOutData);
-bool clearGPUTextures();
-bool wrapupGPU(void);
+#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+CGLContextObj cgl_init();
 #endif
 
+bool initGPU(int*, char**);
+bool configureGPUTextures(unsigned int k, unsigned int vars);
+bool gpuGDAKernel(unsigned int k, unsigned int vars, double t,
+                  float* packedEData, float* packedPiData, float* packedOutData);
+bool clearGPUTextures();
+bool wrapupGPU(void);
+#endif /* HAVE_LIBGLEW */
+
 #endif /* __GPU_H__ */
+
+// Local Variables:
+// mode: c++
+// End:
